@@ -1,8 +1,9 @@
 from unittest import TestCase
 import datetime
 import mock
+import requests
 from fitbit import Fitbit
-from fitbit.exceptions import DeleteError
+from fitbit.exceptions import DeleteError, Timeout
 
 URLBASE = "%s/%s/user" % (Fitbit.API_ENDPOINT, Fitbit.API_VERSION)
 
@@ -24,6 +25,49 @@ class TestBase(TestCase):
         self.assertRaises(exc, getattr(self.fb, funcname), *args, **kwargs)
 
 
+class TimeoutTest(TestCase):
+
+    def setUp(self):
+        self.fb = Fitbit('x', 'y')
+        self.fb_timeout = Fitbit('x', 'y', timeout=10)
+
+        self.test_url = 'invalid://do.not.connect'
+
+    def test_fb_without_timeout(self):
+        with mock.patch.object(self.fb.client.session, 'request') as request:
+            mock_response = mock.Mock()
+            mock_response.status_code = 200
+            mock_response.content = b'{}'
+            request.return_value = mock_response
+            result = self.fb.make_request(self.test_url)
+
+        request.assert_called_once()
+        self.assertNotIn('timeout', request.call_args[1])
+        self.assertEqual({}, result)
+
+    def test_fb_with_timeout__timing_out(self):
+        with mock.patch.object(self.fb_timeout.client.session, 'request') as request:
+            request.side_effect = requests.Timeout('Timed out')
+            with self.assertRaisesRegexp(Timeout, 'Timed out'):
+                self.fb_timeout.make_request(self.test_url)
+
+        request.assert_called_once()
+        self.assertEqual(10, request.call_args[1]['timeout'])
+
+    def test_fb_with_timeout__not_timing_out(self):
+        with mock.patch.object(self.fb_timeout.client.session, 'request') as request:
+            mock_response = mock.Mock()
+            mock_response.status_code = 200
+            mock_response.content = b'{}'
+            request.return_value = mock_response
+
+            result = self.fb_timeout.make_request(self.test_url)
+
+        request.assert_called_once()
+        self.assertEqual(10, request.call_args[1]['timeout'])
+        self.assertEqual({}, result)
+
+
 class APITest(TestBase):
     """
     Tests for python-fitbit API, not directly involved in getting
@@ -210,12 +254,12 @@ class DeleteCollectionResourceTest(TestBase):
 class ResourceAccessTest(TestBase):
     """
     Class for testing the Fitbit Resource Access API:
-    https://wiki.fitbit.com/display/API/Fitbit+Resource+Access+API
+    https://dev.fitbit.com/docs/
     """
     def test_user_profile_get(self):
         """
         Test getting a user profile.
-        https://wiki.fitbit.com/display/API/API-Get-User-Info
+        https://dev.fitbit.com/docs/user/
 
         Tests the following HTTP method/URLs:
         GET https://api.fitbit.com/1/user/FOO/profile.json
@@ -230,7 +274,7 @@ class ResourceAccessTest(TestBase):
     def test_user_profile_update(self):
         """
         Test updating a user profile.
-        https://wiki.fitbit.com/display/API/API-Update-User-Info
+        https://dev.fitbit.com/docs/user/#update-profile
 
         Tests the following HTTP method/URLs:
         POST https://api.fitbit.com/1/user/-/profile.json
@@ -441,7 +485,7 @@ class ResourceAccessTest(TestBase):
     def test_bodyweight(self):
         """
         Tests for retrieving body weight measurements.
-        https://wiki.fitbit.com/display/API/API-Get-Body-Weight
+        https://dev.fitbit.com/docs/body/#get-weight-logs
         Tests the following methods/URLs:
         GET https://api.fitbit.com/1/user/-/body/log/weight/date/1992-05-12.json
         GET https://api.fitbit.com/1/user/BAR/body/log/weight/date/1992-05-12/1998-12-31.json
@@ -483,7 +527,7 @@ class ResourceAccessTest(TestBase):
     def test_bodyfat(self):
         """
         Tests for retrieving bodyfat measurements.
-        https://wiki.fitbit.com/display/API/API-Get-Body-Fat
+        https://dev.fitbit.com/docs/body/#get-body-fat-logs
         Tests the following methods/URLs:
         GET https://api.fitbit.com/1/user/-/body/log/fat/date/1992-05-12.json
         GET https://api.fitbit.com/1/user/BAR/body/log/fat/date/1992-05-12/1998-12-31.json
@@ -608,7 +652,7 @@ class ResourceAccessTest(TestBase):
 class SubscriptionsTest(TestBase):
     """
     Class for testing the Fitbit Subscriptions API:
-    https://wiki.fitbit.com/display/API/Fitbit+Subscriptions+API
+    https://dev.fitbit.com/docs/subscriptions/
     """
 
     def test_subscriptions(self):
@@ -637,7 +681,7 @@ class SubscriptionsTest(TestBase):
 class PartnerAPITest(TestBase):
     """
     Class for testing the Fitbit Partner API:
-    https://wiki.fitbit.com/display/API/Fitbit+Partner+API
+    https://dev.fitbit.com/docs/
     """
 
     def _test_intraday_timeseries(self, resource, base_date, detail_level,
@@ -652,7 +696,7 @@ class PartnerAPITest(TestBase):
     def test_intraday_timeseries(self):
         """
         Intraday Time Series tests:
-        https://wiki.fitbit.com/display/API/API-Get-Intraday-Time-Series
+        https://dev.fitbit.com/docs/activity/#get-activity-intraday-time-series
 
         Tests the following methods/URLs:
         GET https://api.fitbit.com/1/user/-/FOO/date/1918-05-11/1d/1min.json
